@@ -66,6 +66,7 @@ new KinesisStreamsToLambda(scope: Construct, id: string, props: KinesisStreamsTo
 |kinesisStreamProps?|[`kinesis.StreamProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-kinesis.StreamProps.html)|Optional user-provided props to override the default props for the Kinesis stream.|
 |existingStreamObj?|[`kinesis.Stream`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-kinesis.Stream.html)|Existing instance of Kinesis Stream, if this is set then kinesisStreamProps is ignored.|
 |kinesisEventSourceProps?|[`aws-lambda-event-sources.KinesisEventSourceProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-lambda-event-sources.KinesisEventSourceProps.html)|Optional user-provided props to override the default props for the Lambda event source mapping.|
+|createCloudWatchAlarms|`boolean`|Whether to create recommended CloudWatch alarms|
 
 ## Pattern Properties
 
@@ -74,6 +75,7 @@ new KinesisStreamsToLambda(scope: Construct, id: string, props: KinesisStreamsTo
 |kinesisStream|[`kinesis.Stream`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-kinesis.Stream.html)|Returns an instance of the Kinesis stream created by the pattern.|
 |lambdaFunction|[`lambda.Function`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-lambda.Function.html)|Returns an instance of the Lambda function created by the pattern.|
 |kinesisStreamRole|[`iam.Role`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-iam.Role.html)|Returns an instance of the iam.Role created by the construct for Kinesis stream.|
+|cloudwatchAlarms?|[`cloudwatch.Alarm[]`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-cloudwatch.Alarm.html)|Returns a list of cloudwatch.Alarm created by the construct|
 
 ## Default settings
 
@@ -134,6 +136,7 @@ class KinesisStreamsToLambda(
         scope: aws_cdk.core.Construct,
         id: builtins.str,
         *,
+        create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
         deploy_sqs_dlq_queue: typing.Optional[builtins.bool] = None,
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
         existing_stream_obj: typing.Optional[aws_cdk.aws_kinesis.Stream] = None,
@@ -145,6 +148,7 @@ class KinesisStreamsToLambda(
         """
         :param scope: - represents the scope for all the resources.
         :param id: - this is a a scope-unique id.
+        :param create_cloud_watch_alarms: Whether to create recommended CloudWatch alarms. Default: - Alarms are created
         :param deploy_sqs_dlq_queue: Whether to deploy a SQS dead letter queue when a data record reaches the Maximum Retry Attempts or Maximum Record Age, its metadata like shard ID and stream ARN will be sent to an SQS queue. Default: - true.
         :param existing_lambda_obj: Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored. Default: - None
         :param existing_stream_obj: Existing instance of Kinesis Stream, if this is set then kinesisStreamProps is ignored. Default: - None
@@ -158,6 +162,7 @@ class KinesisStreamsToLambda(
         :summary: Constructs a new instance of the KinesisStreamsToLambda class.
         """
         props = KinesisStreamsToLambdaProps(
+            create_cloud_watch_alarms=create_cloud_watch_alarms,
             deploy_sqs_dlq_queue=deploy_sqs_dlq_queue,
             existing_lambda_obj=existing_lambda_obj,
             existing_stream_obj=existing_stream_obj,
@@ -169,11 +174,6 @@ class KinesisStreamsToLambda(
 
         jsii.create(KinesisStreamsToLambda, self, [scope, id, props])
 
-    @builtins.property # type: ignore
-    @jsii.member(jsii_name="cloudwatchAlarms")
-    def cloudwatch_alarms(self) -> typing.List[aws_cdk.aws_cloudwatch.Alarm]:
-        return jsii.get(self, "cloudwatchAlarms")
-
     @builtins.property # type: ignore
     @jsii.member(jsii_name="kinesisStream")
     def kinesis_stream(self) -> aws_cdk.aws_kinesis.Stream:
@@ -184,11 +184,19 @@ class KinesisStreamsToLambda(
     def lambda_function(self) -> aws_cdk.aws_lambda.Function:
         return jsii.get(self, "lambdaFunction")
 
+    @builtins.property # type: ignore
+    @jsii.member(jsii_name="cloudwatchAlarms")
+    def cloudwatch_alarms(
+        self,
+    ) -> typing.Optional[typing.List[aws_cdk.aws_cloudwatch.Alarm]]:
+        return jsii.get(self, "cloudwatchAlarms")
+
 
 @jsii.data_type(
     jsii_type="@aws-solutions-constructs/aws-kinesisstreams-lambda.KinesisStreamsToLambdaProps",
     jsii_struct_bases=[],
     name_mapping={
+        "create_cloud_watch_alarms": "createCloudWatchAlarms",
         "deploy_sqs_dlq_queue": "deploySqsDlqQueue",
         "existing_lambda_obj": "existingLambdaObj",
         "existing_stream_obj": "existingStreamObj",
@@ -202,6 +210,7 @@ class KinesisStreamsToLambdaProps:
     def __init__(
         self,
         *,
+        create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
         deploy_sqs_dlq_queue: typing.Optional[builtins.bool] = None,
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
         existing_stream_obj: typing.Optional[aws_cdk.aws_kinesis.Stream] = None,
@@ -212,6 +221,7 @@ class KinesisStreamsToLambdaProps:
     ) -> None:
         """The properties for the KinesisStreamsToLambda class.
 
+        :param create_cloud_watch_alarms: Whether to create recommended CloudWatch alarms. Default: - Alarms are created
         :param deploy_sqs_dlq_queue: Whether to deploy a SQS dead letter queue when a data record reaches the Maximum Retry Attempts or Maximum Record Age, its metadata like shard ID and stream ARN will be sent to an SQS queue. Default: - true.
         :param existing_lambda_obj: Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored. Default: - None
         :param existing_stream_obj: Existing instance of Kinesis Stream, if this is set then kinesisStreamProps is ignored. Default: - None
@@ -227,6 +237,8 @@ class KinesisStreamsToLambdaProps:
         if isinstance(sqs_dlq_queue_props, dict):
             sqs_dlq_queue_props = aws_cdk.aws_sqs.QueueProps(**sqs_dlq_queue_props)
         self._values: typing.Dict[str, typing.Any] = {}
+        if create_cloud_watch_alarms is not None:
+            self._values["create_cloud_watch_alarms"] = create_cloud_watch_alarms
         if deploy_sqs_dlq_queue is not None:
             self._values["deploy_sqs_dlq_queue"] = deploy_sqs_dlq_queue
         if existing_lambda_obj is not None:
@@ -242,6 +254,15 @@ class KinesisStreamsToLambdaProps:
         if sqs_dlq_queue_props is not None:
             self._values["sqs_dlq_queue_props"] = sqs_dlq_queue_props
 
+    @builtins.property
+    def create_cloud_watch_alarms(self) -> typing.Optional[builtins.bool]:
+        """Whether to create recommended CloudWatch alarms.
+
+        :default: - Alarms are created
+        """
+        result = self._values.get("create_cloud_watch_alarms")
+        return result
+
     @builtins.property
     def deploy_sqs_dlq_queue(self) -> typing.Optional[builtins.bool]:
         """Whether to deploy a SQS dead letter queue when a data record reaches the Maximum Retry Attempts or Maximum Record Age, its metadata like shard ID and stream ARN will be sent to an SQS queue.
